#
# spec file for package gnome-online-accounts
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-online-accounts
Version:        3.52.3.1
Release:        1.1
Summary:        GNOME service to access online accounts
License:        LGPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GnomeOnlineAccounts
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gcr-4)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.52
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.52
BuildRequires:  pkgconfig(glib-2.0) >= 2.52
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.6.2
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(gtk4) >= 4.10
BuildRequires:  pkgconfig(javascriptcoregtk-4.1)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4
BuildRequires:  pkgconfig(libkeyutils)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(rest-1.0)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(webkit2gtk-4.1)
# p11-kit is not 'strictly' seen a requirement, but without it none of the SSL/TLS
# Certificates are considered valid, which results in a really bad experience.
Requires:       p11-kit >= 0.16

%description
gnome-online-accounts provides interfaces so applications and
libraries in GNOME can access the user's online accounts.

%package -n libgoa-1_0-0
Summary:        GNOME service to access online accounts -- Client Library
Group:          System/Libraries
Recommends:     %{name}

%description -n libgoa-1_0-0
gnome-online-accounts provides interfaces so applications and
libraries in GNOME can access the user's online accounts.

%package -n typelib-1_0-Goa-1_0
Summary:        GNOME service to access online accounts -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Goa-1_0
gnome-online-accounts provides interfaces so applications and
libraries in GNOME can access the user's online accounts.

This package provides the GObject Introspection bindings for the libgoa
client library.

%package -n libgoa-backend-1_0-2
Summary:        GNOME service to access online accounts -- Backend Library
Group:          System/Libraries
Recommends:     %{name}

%description -n libgoa-backend-1_0-2
gnome-online-accounts provides interfaces so applications and
libraries in GNOME can access the user's online accounts.

%package devel
Summary:        GNOME service to access online accounts -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgoa-1_0-0 = %{version}
Requires:       libgoa-backend-1_0-2 = %{version}
Requires:       typelib-1_0-Goa-1_0 = %{version}

%description devel
gnome-online-accounts provides interfaces so applications and
libraries in GNOME can access the user's online accounts.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D gtk_doc=true \
	-D exchange=true \
	-D google=true \
	-D imap_smtp=true \
	-D kerberos=true \
	-D owncloud=true \
	-D windows_live=true \
	-D fedora=false \
	-D man=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%ldconfig_scriptlets -n libgoa-1_0-0
%ldconfig_scriptlets -n libgoa-backend-1_0-2

%files
%license COPYING
%doc NEWS
%{_libexecdir}/goa-daemon
%{_datadir}/dbus-1/services/org.gnome.OnlineAccounts.service
%{_datadir}/glib-2.0/schemas/org.gnome.online-accounts.gschema.xml
%{_datadir}/icons/hicolor/*/apps/goa-account*.svg
%{_mandir}/man8/goa-daemon.8%{?ext_man}
%dir %{_libdir}/goa-1.0
%{_libexecdir}/goa-identity-service
%{_datadir}/dbus-1/services/org.gnome.Identity.service
%{_libexecdir}/goa-oauth2-handler
%{_datadir}/applications/org.gnome.OnlineAccounts.OAuth2.desktop

%files -n libgoa-1_0-0
%{_libdir}/libgoa-1.0.so.*

%files -n typelib-1_0-Goa-1_0
%{_libdir}/girepository-1.0/Goa-1.0.typelib

%files -n libgoa-backend-1_0-2
%{_libdir}/libgoa-backend-1.0.so.*

%files devel
%dir %{_datadir}/doc/gnome-online-accounts
%doc %{_datadir}/doc/gnome-online-accounts/Goa-1.0
%{_includedir}/goa-1.0/
%dir %{_libdir}/goa-1.0
%{_libdir}/goa-1.0/include/
%{_libdir}/libgoa-1.0.so
%{_libdir}/libgoa-backend-1.0.so
%{_libdir}/pkgconfig/goa-1.0.pc
%{_libdir}/pkgconfig/goa-backend-1.0.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/goa-1.0.deps
%{_datadir}/vala/vapi/goa-1.0.vapi

%files lang -f %{name}.lang

%changelog
* Sat Jan 11 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.52.3.1:
  + Bugs fixed:
  - Unable to Sign In to Microsoft Exchange account
  - Missing kerberos password not detected
  - Fail faster - don't wait 120 seconds to timeout
  - goadaemon: Changes around "no provider" runtime warnings
* Sat Nov 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.52.2:
  + Bugs fixed:
  - goadavclient.c: add WebDAV default candidate to test
  - goafedoraprovider: fix use-after-free
  + Updated translations.
* Sun Oct 20 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.52.1:
  + Bugs fixed:
  - goakerberosprovider: don't assume all errors are auth errors
  - goaoauthprovider: fix expected NULL GError
  + Updated translations.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.52.0:
  + Updated translations.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.51.3:
  + Accessibility fixes and event announcements
  + Updated translations.
- Changes from version 3.51.2:
  + Adopt a less aggressive notification policy
  + Updated translations.
- Changes from version 3.51.1:
  + Enable Mail, Calendar & Contacts for Microsoft 365
  + Improvements to Microsoft 365 setup dialog
  + Use AdwButtonRow when applicable
  + Allow overriding dependencies supporting built as a meson wrap
  + Refactor web browser authentication flow as a discrete task
  + Improve error reporting and notification for providers
  + Document configuration files used by the daemon
  + Correctly save and reset settings for TLS certificate errors
  + Updated translations.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.51.0:
  + Support Mail Autoconfig XML for IMAP/SMTP services
  + Support SRV lookups for DAV services
  + Support Linux's KEYRING notification pipe for Kerberos
  + Ability to restrict which services of a particular account type
    are available
  + Add version CLI flag for goa-daemon
  + Port to AdwDialog and AdwAlertDialog
  + Accept GtkWidget as a top-level for account setup
  + Port documentation to gi-docgen
  + Documentation and manual pages are enabled by default
  + Fixes for bugs found by Coverity Scan
  + Fix libsoup error handling
  + Translation fixes and missing strings
  + Updated translations.
- Add pkgconfig(libkeyutils) and pkgconfig(gi-docgen)
  BuildRequires, new dependencies.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.50.5:
  + goaimapsmtpprovider: quick fix for yahoo auto-detect
  + Updated translations.
* Mon Aug  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.50.4:
  + Allow editing the details for Exchange accounts when
    re-authenticating.
  + Correctly save and reset settings for TLS certificate errors.
* Sun Jun 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.50.3:
  + WebDAV: minor fixes for accounts with app passwords
  + Fix libsoup error handling
  + Updated translations.
* Mon May 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.50.2:
  + Setup Dialog:
  - fix provider icon style.
  - fix dialog not closing when cancelled.
  + Exchange: fix account setup field verification.
  + Microsoft 365:
  - fix account storage.
  - fix identity retrieval.
  - fix email retrieval.
  + WebDAV:
  - fix Fastmail and mailbox.org endpoints.
  - fix for content-restricted app passwords.
  + Updated translations.
* Fri Apr 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.50.1:
  + Fix translation domain in account dialogs.
  + Fix OAuth 2.0 URI handler for some users.
  + Fix crash in Kerberos/Fedora provider.
  + Improved WebDAV support for Fastmail and mailbox.org.
  + Fixes for WebDAV discovery.
  + OAuth 2.0 PKCE support.
  + Fix issues caught by static analysis.
  + Update Microsoft Client ID.
  + Updated translations.
* Sun Mar 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.50.0:
  + Updated translations.
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.49.4:
  + Update dependencies in the GoaBackend pkgconfig.
- Changes from version 3.94.3:
  + Bump GoaBacked soname to 2.0.0.
  + Fix nested modal windows.
  + Simplified account setup UX.
  + Updates to user visible labels and descriptions.
  + Updated translations.
* Tue Feb 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.49.2:
  + Fix a use-after-free error.
  + Set a minimum height for dialogs.
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.49.1:
  + Add Microsoft 365 provider.
  + Port to GTK4/Adwaita and an async API.
  + Remove nautilus-floating-bar.
  + Derive the Fedora provider from Kerberos.
  + Migrate existing WebDAV accounts.
  + Update provider icons.
  + Updated translations.
- Replace pkgconfig(gtk+-3.0) BuildRequires with pkgconfig(gtk4)
  and pkgconfig(libadwaita-1): follow upstreams port to GTK 4.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.49.0:
  + Depend on GCR4.
  + Remove the media server provider.
  + Remove the Last.fm provider.
  + Add WebDAV base provider.
  + Remove the webview and WebKit dependency.
  + Updated translations.
- Convert to source service for easier updating.
- Drop 0001-google-Remove-Photos-support.patch: fixed upstream.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.48.0:
  + Updated translations.
- Rebase patch with quilt.
* Mon Feb 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.47.1:
  + Build fixes
  + Expired Kerberos tickets not re-acquired on resume from suspend
  + Update CalDAV/CardDAV OwnCloud endpoints
  + Attempt to cope with multiple credential caches per identity
  + Error in solving Nextcloud account address
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.46.0:
  + Build system fixes with recent Meson.
  + Updated translations.
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 0001-google-Remove-Photos-support.patch: google: Remove
  Photos support. In theory, support for photos is still desired.
  However, right now the implementation of the Google PicasaWeb API
  in libgdata no longer works. Until that's fixed, there's no point
  in advertising support for photos. See
  https://gitlab.gnome.org/GNOME/gnome-online-accounts/-/issues/63
* Tue Aug  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.45.2:
  + Use debugging messages instead of warnings.
  + Fix documentation build.
  + Updated translations.
- Enable build of documentation again.
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.45.1:
  + Removed providers:
  - Foursquare
  - Facebook
  - Flickr
  + Port to libsoup3
  + Port to librest-1.0
  + Drop the Autotools build
  + Update the Google OAuth2 provider
- Add meson BuildRequires and macros, switch to meson buildsystem.
- Use ldconfig_scriptlets macro for post(un) handling.
- Replace BuildRequires following upstream changes:
  + Drop pkgconfig(libsoup-2.4), pkgconfig(rest-0.7) and
    pkgconfig(webkit2gtk-4.0).
  + Add pkgconfig(javascriptcoregtk-4.1), pkgconfig(libsoup-3.0),
    pkgconfig(rest-1.0) and pkgconfig(webkit2gtk-4.1).
- Do not build gtk-docs as it is currently broken.
* Thu Mar 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.44.0:
  + Bugs fixed:
  - Add .gitlab-ci.yml
  - Update Fedora logo
  - Silence -Wincompatible-pointer-types with GCC 11
  + Updated translations.
* Tue Oct 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.43.1:
  + Remove Documents support.
  + Bugs fixed:
  - glgo#GNOME/gnome-online-accounts!67 doc: Update.
  - glgo#GNOME/gnome-online-accounts!68 dbus: Add missing since
    tag for IsSupportedProvider.
  + Updated translations.
* Tue Oct 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.40.1:
  + Bugs fixed: glgo#GNOME/gnome-online-accounts!68 dbus: Add
    missing since tag for IsSupportedProvider.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Apr 25 2021 Michael Gorse <mgorse@suse.com>
- Update to version 3.40.0:
  + No changes.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.39.92:
  + Last.fm is enabled by default.
  + Bugs fixed:
  - web-extension-main: Remove unnecessary and unused entry
    point.
  - kerberos-identity: Handle information-only prompts when
    signing in.
  - client: Mention that goa_client_get_manager might return
    NULL.
  + Updated translations.
* Sat Oct 10 2020 Michael Gorse <mgorse@suse.com>
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Bugs fixed:
  - daemon: Remove the --no-sigint flag and always handle SIGINT.
  - webview: Enable web process sandbox.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36.0:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Polish some rough edges in the Meson build.
  + Various build fixes.
  + kerberos-identity-manager: Remove unused signal handler ID.
  + daemon, dbus: Enable checking if a provider type is supported.
- Changes from version 3.35.3:
  + Remove Pocket.
  + Bugs fixed:
  - Drop the priv pointer from the GObject instance structures.
  - Port away from deprecated GLib API like g_memove and
    g_get_current_time.
  - webview: Port to JSCValue.
  - Use the G_DECLARE_* macros to reduce GObject boilerplate.
  - Add Exchange and Last.fm icons.
- Changes from version 3.35.1:
  + Updated translations.
- Drop --enable-pocket configure parameter: no longer supported.
* Wed Oct 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Bugs fixed: icons: Unbreak providers without any visual
    identity.
  + Updated translations.
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.91:
  + Support Fedora Account System.
  + Bugs fixed:
  - owncloud: Use "Nextcloud", not "ownCloud", in user-visible
    errors.
  - build: Allow building with gettext ≥ 0.20.
  - webview: Make it more flexible in terms of its size.
  - kerberos: Use GTask's task data slot to leverage the
    compiler.
  - daemon: Return a D-Bus error if AddAccount fails to list all
    providers.
  - kerberos: Use GTask's task data slot to leverage the
    compiler.
  - build: Support the use of g_autolist with GoaObject.
  - Port to GTask from GSimpleAsyncResult.
  + Updated translations.
* Mon Mar 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Bugs fixed:
  - icons: Replace PNGs with SVGs and add symbolics.
  - google: Only request the email field when getting the user's
    identity.
  - alarm: Refresh Kerberos tickets after a suspended system is
    resumed.
  + Updated translations.
* Tue Feb 12 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Remove Todoist.
  + Bugs fixed:
  - build: Don't define _POSIX_PTHREAD_SEMANTICS and _REENTRANT.
  - identity: Port away from deprecated g_type_class_add_private.
  - Port to GTask from GSimpleAsyncResult.
  + Updated translations.
- No longer pass --disable-telepathy to configure, no longer needed
  nor recognized.
* Mon Feb 11 2019 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + google: Only request the email field when getting the user's
    identity.
  + Updated translations.
* Thu Jan 17 2019 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + alarm: Refresh Kerberos tickets after a suspended system is
    resumed (bgo#796095).
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Thu Aug 16 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + build: Fix #FooObject style links.
  + Remove additional unnecessary GDestroyNotify casts.
  + build: Silence warning about _FORTIFY_SOURCE requiring
    optimization.
- Drop gnome-online-accounts-fix-build.patch: Fixed upstream.
* Thu Aug 16 2018 bjorn.lie@gmail.com
- Add gnome-online-accounts-fix-build.patch: Fix build with new
  glib.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.29.4:
  + Port to meson build system.
  + Updated translations.
- Pass --enable-documentation to configure, now needed to build man
  pages.
* Fri Apr 20 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Remove Twitter support (bgo#795322)
  + Updated translations.
- Drop:
  + intltool BuildRequires: nothing depends on it anymore. The
    package fully uses Gettext now.
  + update-desktop-files BuildRequires: this is no longer needed.
* Wed Apr  4 2018 fcrozat@suse.com
- Disable telepathy support, it isn't used for years. Remove
  BuildRequires(libaccounts-glib/telepathy-glib) accordingly.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Thu Mar 15 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  2 2018 bjorn.lie@gmail.com
- Don't enable Media Server option. It is an experimental untested
  feature that was only used in GNOME Photos and the GNOME Photos
  maintainer recommended we disable it, so stop passing
  - -enable-media-server to configure, pass --disable-media-server
  instead.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update inside-spec comment: don't remove intltool yet,
  telepathy-account-widgets still depends on it.
* Fri Dec 22 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Bugs fixed:
  - Port to GTask from GSimpleAsyncResult (bgo#764157).
  - Cookies from previous session are not cleared from the web
    view (bgo#781005).
  - Migrate from Intltool to Gettext (bgo#787250).
  + Updated translations.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Remove unneeded %%clean section once RPM does this work itself
  now.
* Fri Dec 15 2017 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + Bug fixed: Make the Git submodules work with Web proxies
    (bgo#788769).
  + Updated translations.
- Add conditional use for translation-update-upstream: sle-only
  requirement.
- Drop parameter --with-cheese in %%configure: no longer available.
- Update Url to the current application's wiki page:
  https://wiki.gnome.org/Projects/GnomeOnlineAccounts
- Add pkgconfig(*) BuildRequires for alignment with configure.ac:
  gio-2.0 and glib-2.0.
- Run spec-cleaner to get the respective pkgconfigs of
  gobject-introspection-devel and gtk-doc:
  pkgconfig(gobject-introspection-1.0) and pkgconfig(gtk-doc).
* Thu Dec 14 2017 zaitor@opensuse.org
- Update to version 3.26.2:
  + Bugs fixed: bgo#789187.
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Updated translations.
* Wed Sep 13 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Bugs fixed: bgo#758716, bgo#785649, bgo#785726, bgo#786007.
  + Updated translations.
* Fri Aug  4 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Bugs fixed: bgo#784512, bgo#784513, bgo#784944.
  + Updated translations.
* Fri Aug  4 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Support Flickr (bgo#780138).
  + Telepathy is disabled by default.
  + Bugs fixed: bgo#686131, bgo#760440, bgo#770542, bgo#772305,
    bgo#779368.
  + Updated translations.
* Thu Aug  3 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + backend: Use constructor to setup gettext (bgo#760440).
  + facebook: Make it work with Graph API > 2.3 (bgo#785726).
  + Updated translations.
* Mon May 29 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Thu Mar 16 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Bugs fixed: bgo#778416, bgo#778417, bgo#779548.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + bgo#778353: Disconnect all signal handlers from the GtkDialog
    once add_account is done.
  + bgo#778779: Improve the spacing between UI elements.
  + Updated translations.
* Sun Feb 19 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + bgo#772205: Use double quotes instead of single quotes in
    translatable strings.
  + updated translations.
* Sun Feb 19 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Bugs fixed: bgo#764157, bgo#765121, bgo#768515, bgo#776871,
    bgo#776897, bgo#776906.
  + Updated translations.
* Sun Feb 19 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + New API key for Google.
  + Bugs fixed: bgo#738315, bgo#769267, bgo#774176, bgo#774205.
  + Updated translations.
* Sun Feb 19 2017 dimstar@opensuse.org
- Replace krb5-mini-devel BuildRequires with pkgconfig(krb5): it is
  not our duty to decide between -mini and the real package.
* Sun Feb 19 2017 zaitor@opensuse.org
- Add pkgconfig(vapigen) BuildRequires: Build vala support.
* Tue Jan 10 2017 zaitor@opensuse.org
- Update to version 3.22.4:
  + Bugs fixed: bgo#765121, bgo#776871, bgo#776897.
* Wed Dec 14 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + New API key for Google.
  + Updated translations.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Experimental account templates support (bgo#771366).
  + Updated translations.
* Thu Sep  1 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + bgo#770610: daemon: Clean-up the memory management of our
    GKeyFile instances.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + daemon: Ensure temporary accounts are really removed from the
    keyring (bgo#688041).
  + pocket: Support logging in with a Firefox account (bgo#755386).
  + identity:
  - Don't leak the GoaObject from find_object_with_principal
    (bgo#756431).
  - Silence -Wincompatible-pointer-types (bgo#768808).
  + Port to GTask from GSimpleAsyncResult (bgo#764157).
  + Let goa_provider_show_account have more control over the UI
    (bgo#769213).
  + Updated translations.
* Thu Jul 28 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + identity: Don't leak the invocation when handling SignIn
    (bgo#756431).
  + Port to GTask from GSimpleAsyncResult (bgo#764157).
  + kerberos, telepathy: Stopping goa-daemon removes account or
    expires credentials (bgo#766733).
  + Offer a simple mechanism to introspect the available providers
    and services (bgo#767914).
  + identity: Clean up the credential cache and don't keep trying
    to sign in if we encounter a failure (bgo#768808).
  + kerberos: Don't leak the GSimpleAsyncResult and object_path
    when signing in (bgo#768845).
  + Updated translations.
* Thu Jul 28 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Don't let temporary accounts accumulate in accounts.conf and
    the keyring (bgo#688041).
  + lastfm: Don't forget to update the ret variable (bgo#760991).
  + Skip EnsureCredentials if the account is disabled (bgo#762155).
  + Port to GTask from GSimpleAsyncResult (bgo#764157).
  + Misc usability improvements to the imap-smtp provider
    (bgo#764283).
  + org.gnome.OnlineAccounts.Account:IsTemporary is not being set
    (bgo#765994).
  + kerberos, telepathy: Stopping goa-daemon removes account or
    expires credentials (bgo#766733).
  + Adding a Telepathy account is racy due after adding a headerbar
    (bgo#767299).
  + Updated translations.
* Thu Jul 28 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Port to GTask from GSimpleAsyncResult (bgo#764157).
  + goa-daemon --help shows translated characters as question marks
    on some locales (bgo#765455).
  + Updated translations.
* Thu Jul 28 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Bugs fixed: bgo#756431, bgo#762155, bgo#766733, bgo#768808,
    bgo#768845.
  + Updated translations.
* Fri Jul  8 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + lastfm: Don't forget to update the ret variable (bgo#760991).
  + Misc usability improvements to the imap-smtp provider
    (bgo#764283).
  + org.gnome.OnlineAccounts.Account:IsTemporary is not being set
    (bgo#765994).
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + identity: fix renewal requests for kernel keyring based tickets
    (bgo#756495).
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Wed Mar 16 2016 dimstar@opensuse.org
- Update to version 3.19.92.1:
  + bgo#763078: Documentation missing from tarball.
* Wed Mar 16 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + bgo#756495: identity: don't ignore almost all renewal requests.
  + bgo#761262: alarm, daemon: Avoid using %%m for errors.
  + bgo#761510: Factorize common code in
    GoaBackend::build_object().
  + bgo#762097: httpclient: Don't hard-code "Connection: close" in
    the request headers.
  + bgo#762155: kerberos: Do not use goa_object_peek_* in threaded
    code.
  + bgo#762548: Fix the dialogs' dimensions with newer GTK+.
  + bgo#763078: build: Update autogen.sh from GNOME recommendation.
  + Updated translations.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Bugs fixed: bgo#755316, bgo#756498, bgo#760991, bgo#761188,
    bgo#761510.
  + Updated translations.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Bugs fixed: bgo#758475, bgo#759571, bgo#759828, bgo#760189.
  + Updated translations.
* Wed Feb 17 2016 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Bugs fixed: bgo#751524, bgo#758361.
  + Updated translations.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Bugs fixed: bgo#755316, bgo#757952, bgo#758361.
  + Updated translations.
- Changes from version 3.19.1:
  + Bugs fixed: bgo#752736, bgo#754142, bgo#755168, bgo#755315,
    bgo#756394, bgo#756494, bgo#756759.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.18.4:
  + kerberos: Fail early on ticket request when ticketing disabled
    (bgo#756498).
  + Examples fail if backend is disabled (bgo#758475).
  + Use primary@REALM as the presentation identity for temporary
    accounts (bgo#761188).
  + Updated translations.
* Thu Dec 17 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + Network changes cause authentication token timeouts
    (bgo#751524).
  + imap-smtp: Fix typo in error message (bgo#755316).
  + Crash in mail_client_check_auth_run_cb when goa_mail_auth_run
    fails (bgo#758361).
  + Updated translations.
* Tue Nov 24 2015 dimstar@opensuse.org
- Pass --enable-media-server to configure: enable DLNA provider.
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 3.18.2.1:
  + Fix org.gnome.Identity.service.in is missing from tarball
    (bgo#757952).
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + provider, telepathy: Small leak fixes (bgo#756759).
* Wed Oct 14 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + owncloud: Doesn't work with non-standard ports (bgo#752736).
  + owncloud, exchange: Sanitize HTTP error messages (bgo#755168).
  + lastfm: Leak fixes (bgo#755315).
  + identity:
  - Allow multiple simultaneous sign-in requests from one sender
    (bgo#756394).
  - Don't ever nullify identifier (bgo#756494).
  + Updated translations.
* Tue Sep 22 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + icons: Shiny new Google icons (bgo#754142).
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92.1:
  + bgo#754142: build: Ensure that the new 96x96 HiDpi icons
    actually get installed.
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Support Last.fm (bgo#728621).
  + Bugs fixed: bgo#751128, bgo#754142, bgo#754840.
  + Updated translations.
* Thu Sep 10 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + Add org.gnome.OnlineAccounts.Music D-Bus interface
    (bgo#705969).
  + Bugs fixed: bgo#693578, bgo#750392, bgo#750479, bgo#750897,
    bgo#752270, bgo#752939, bgo#752941, bgo#752964.
  + Updated translations.
* Tue Jun  9 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Foursquare is enabled by default.
  + Bugs fixed: bgo#710764, bgo#739593, bgo#739594, bgo#742680.
  + Updated translations.
- Add pkgconfig(libaccounts-glib) BuildRequires: New dependency.
- Pass --with-cheese=yes and --enable-foursquare to %%configure, we
  want webcam and foursquare support.
* Tue Jun  9 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Refresh credentials at startup and network changes
    (bgo#693578).
  + Avoid NULL pointer dereference when EWS autodiscover fails
    (bgo#750392).
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + telepathy: "use this account for external calls" checkbox is
    not working (bgo#744165).
  + facebook: Restore a wrongly deleted string (bgo#745004).
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Add some spacing between the service name and its switch
    (bgo#746540).
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Remove Yahoo! support (bgo#721061).
  + Bugs fixed: bgo#742680: Port to WebKit2.
  + Updated translations.
- Replace pkgconfig(webkitgtk-3.0) BuildRequires with
  pkgconfig(webkit2gtk-4.0), following upstreams port to WebKit2.
* Tue Feb 24 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Remove Facebook chat support (bgo#745004).
  + ewsclient, httpclient: Stop using deprecated SoupSessionAsync
    (bgo#742651).
  + Updated translations.
* Tue Jan 20 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Bugs fixed: bgo#743044.
  + Updated translations.
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 3.15.3:
  + Support Foursquare (bgo#729837).
  + Updated translations.
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 3.15.2:
  + Bugs fixed:
    bgo#739009: google: Add support for files.
    bgo#739168: facebook: Add fallback to get presentation id.
    bgo#739590: Memory leak fixes.
    bgo#739593: kerberos: A pile of fixes.
  + Updated translations.
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + Support locked accounts (bgo#737656).
  + Bugs fixed: oauth2: Silence uninit_use_in_call from Coverity
    (bgo#736749).
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Bugs fixed: bgo#743044 ewsclient: httpclient: Don't crash or
    deadlock during clean up.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Bugs fixed:
  - bgo#739168: facebook: Add fallback to get presentation id.
  - bgo#739590: Memory leak fixes.
  - bgo#739593: kerberos: A pile of fixes.
* Thu Oct 16 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Bugs fixed: Fix a life-cycle issue that affected
    gnome-initial-setup (bgo#737549).
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Bugs fixed: media-server: Use a hyphen instead of underscore in
    provider type (bgo#736407).
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Add a whitelist for providers (bgo#729173).
  + Support media servers (bgo#730890).
  + Bugs fixed: bgo#693689, bgo#699553, bgo#707299, bgo#729638,
    bgo#731531, bgo#731614.
- Changes from version 3.13.2:
  + Bugs fixed: bgo#728877, bgo#729389, bgo#729638, bgo#729740,
    bgo#730810.
- Changes from version 3.13.1:
  + Remove Twitter support (bgo#660273, bgo#721061).
  + Remove Windows Live chat support (bgo#728787).
  + Bugs fixed: bgo#726353, bgo#726570.
  + Updated translations.
- Enable new media server provider: pass --enable-media-server to
  configure.
* Wed Jul 16 2014 zaitor@opensuse.org
- Update to version 3.12.4:
  + Bugs fixed: bgo#693689 google: Add support for tasks.
* Mon Jun 23 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Bugs fixed: bgo#699553, bgo#730041, bgo#730810.
  + Updated translations.
* Fri Jun 13 2014 mgorse@suse.com
- Update to version 3.10.5:
  + Remove Windows Live chat support (bgo#728787)
  + Bugs fixed:
  - bgo#699553 ewsclient: Correctly cancel pending messages on
    success
  - bgo#729864 goaalarm: small memory leak fix
  - bgo#729865 identity: fix another principal leak
  - bgo#729874 identity: don't leak default credentials cache
  - bgo#730041 ewsclient: Autodiscover XML can contain multiple
    Protocol elements
  - bgo#730810 flickr: Use SSL
  + Updated translations: Romanian
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Remove Windows Live chat support (bgo#728787).
  + Bugs fixed: bgo#729718, bgo#729864, bgo#729865, bgo#729874.
  + Updated translations.
* Fri May 16 2014 mgorse@suse.com
- Update to version 3.10.4:
  + Bugs fixed:
  - bgo#726609 Popup is too small to display Facebook
    authorization
  - bgo#727896 IdentityService crashes on startup if
    KerberosIdentityManager could not be created
  - bgo#727957 Broken check for non-empty strings
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Popup is too small to display Facebook authorization
    (bgo#726609).
  + IdentityService crashes on startup if KerberosIdentityManager
    could not be created (bgo#727896).
  + Broken check for non-empty strings (bgo#727957).
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Thu Mar 20 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + Bugs fixed: bgo#726353 kerberos: Leaking credentials, cursors,
    principals and GDateTime.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + bgo#726353: kerberos: Leaking credentials, cursors, principals
    and GDateTime.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
- Remove traces of twitter support (disabled since version 3.7,91):
  Support has been removed from the codebase.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Pocket is enabled by default (bgo#724300).
  + Bugs fixed: Replace GOA logging with GLib logging (bgo#723926).
  + Updated translations.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Remove unused GoaSpinnerButton widget (bgo#689609).
  + imap-smtp: Export the SASL mechanism used for SMTP
    (bgo#720262).
  + google: Add support for printers (bgo#723370).
  + Updated translations.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Support Pocket (bgo#704564).
  + Replace deprecated GtkStock (bgo#720632).
  + Updated translations.
* Wed Dec 18 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Bugs fixed: bgo#701500, bgo#712535, bgo#712843, bgo#720446.
  + Updated translations.
* Wed Nov 20 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Support kernel keyring based Kerberos accounts (bgo#707402,
    bgo#710116).
  + Support Windows Live mail (bgo#709393).
  + Bugs fixed: bgo#699491, bgo#704564, bgo#705395, bgo#706614,
    bgo#706664, bgo#706803, bgo#706894, bgo#706987, bgo#707005,
    bgo#707006, bgo#707435, bgo#707916, bgo#708399, bgo#708462,
    bgo#708832, bgo#708975, bgo#709103, bgo#709570, bgo#709953,
    bgo#709955, bgo#710363, bgo#711472, bgo#711572, bgo#711696.
  + Updated translations.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + bgo#708399: telepathy: Choose better icons.
  + bgo#710363: Adapt to changes in the redirect URI used by
    Facebook.
  + bgo#711472: live: Does not update MailEnabled.
  + bgo#711572: kerberos: don't crash if keyring credentials
    disappear.
  + bgo#711696: kerberos: Leaking timerfds when we fall back to
    polling the ccache.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Support kernel keyring based Kerberos accounts (bgo#707402,
    bgo#710116).
  + Support Windows Live mail (bgo#709393).
  + Bugs fixed: bgo#708462, bgo#708832, bgo#708975, bgo#709103,
    bgo#709570, bgo#709953, bgo#709955.
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Kerberos: crashes or causes 100%% CPU usage (bgo#705395).
  + Updated translations.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Google: Add the OAuth2 scope for CardDAV (bgo#707916).
  + Updated translations.
* Mon Sep  2 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Bugs fixed: bgo#699491, bgo#705395, bgo#706614, bgo#706664,
    bgo#706803, bgo#706894, bgo#706987, bgo#707005, bgo#707006.
  + Updated translations.
- Drop gnome-online-accounts-webkitgtk-2.1.90.patch: fixed
  upstream.
- Remove gsettings schema calls from post/postun: upstream ships
  this file now with empathy instead of gnome-online-accounts.
* Sun Sep  1 2013 zaitor@opensuse.org
- Add gnome-online-accounts-webkitgtk-2.1.90.patch: Adapt to
  webkitgtk 2.1.90 API.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Support Telepathy accounts (bgo#696267).
  + Bugs fixed: bgo#705366, bgo#706074.
  + Updated translations.
- Add pkgconfig(telepathy-glib) BuildRequires: new dependency for
  Telepathy account support.
- Add glib schema handling scriptlets to post/postun.
- Rename libgoa-backend-1_0-0 subpackage to libgoa-backend-1_0-1,
  following upstreams soname bump.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Fixed license notices to be consistently LGPLv2+.
  + Updated translations.
- Update License tag to LGPL-2.0+, following upstreams
  clarification.
* Wed Jul 10 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Flickr is enabled by default.
  + Bugs fixed: bgo#678151, bgo#688364, bgo#692176, bgo#692177,
    bgo#701500, bgo#702263, bgo#702514.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Bugs fixed: bgo#669040, bgo#694313, bgo#695118, bgo#695768,
    bgo#695886, bgo#698178, bgo#698203.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Bugs fixed: bgo#657761, bgo#695355, bgo#695559, bgo#695802,
    bgo#695888, bgo#696085.
  + Updated translations.
* Thu Mar 14 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Mon Mar 11 2013 dimstar@opensuse.org
- Swicth with_twitter to 0: it's known to cause crashes at the
  moment and is not ready to be used.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + IMAP/SMTP is enabled by default.
  + Bugs fixed: bgo#660882, bgo#695065, bgo#695074, bgo#695106.
  + Updated translations.
- Drop pkgconfig(libnotify) BuildRequires: no longer needed.
- Add p11-kit Requires: needed in order to validate SSL/TLS
  certificates. Strictly speaking, it could be recommended only,
  but the user experience without it is terrible, as no certificate
  is considered valid.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Support IMAP/SMTP (bgo#692736).
  + Bugs fixed: bgo#692936, bgo#693273.
  + Updated translations.
- Pass --enable-imap-smtp to configure for the new IMAP/SMTP
  provider.
- Drop gnome-online-accounts-implicit.patch: fixed upstream.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + ownCloud is enabled by default.
  + Bugs fixed: bgo#689645, bgo#692251, bgo#692276, bgo#692284,
    bgo#692285, bgo#692286, bgo#692768, bgo#693214.
  + Updated translations.
- Add gnome-online-accounts-implicit.patch: Fix an implicit
  declaration.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + google: Make the configure options match OAuth 2.0 lingo
    (bgo#689770).
  + webview: don't set the OSD style class on the whole overlay
    (bgo#691122).
  + identity: Don't leak the GoaKerberosIdentity (bgo#691142).
  + Updated translations.
- Replace pkgconfig(libsoup-gnome-2.4) BuildRequires with
  pkgconfig(libsoup-2.4), following upstream.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + build: Fix passing arguments to configure from autogen.sh
    (bgo#689516).
  + Spinners are white and don't spin (bgo#689609).
  + Make the cancel buttons work (bgo#689642).
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Add provider groups
  + Bugs fixed: bgo#660573, bgo#686519, bgo#687578, bgo#687632,
    bgo#687930, bgo#687962, bgo#688018.
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Implement OAuth 2.0 for Google (bgo#661065)
  + Support ownCloud (bgo#660573)
  + Support Flickr (bgo#678151)
  + Bugs fixed: bgo#683692, bgo#685876, bgo#686410, bgo#686415,
    bgo#686416, bgo#686561
  + Updated translations.
- Pass --enable-flickr and --enable-owncloud to confiugre.
- Switch with_twitter defines to 1, as twitter support is back.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.6.3:
  + bgo#693214: Guard against invalid SSL certificates
    (CVE-2013-0240)
  + bgo#695106: Do not send the credentials before notifying the
    user of an invalid SSL certificate (CVE-2013-1799).
- Drop gnome-online-accounts-CVE-2013-0240.patch: fixed upstream.
* Wed Feb  6 2013 dimstar@opensuse.org
- Add gnome-online-accounts-CVE-2013-0240.patch: goa fails to
  verify SSL certificates when creating accounts (bnc#802409,
  bgo#693214, CVE-2013--240).
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Bugs fixed: bgo#685876, bgo#686410, bgo#686415, bgo#686416,
    bgo#687578, bgo#687632, bgo#687962, bgo#688018
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Bugs fixed: bgo#660932, bgo#681729, bgo#683911, bgo#683968.
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Ensure that all dialogs have consistent and meaningful strings
  (bgo#683692).
  + Updated translations.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Removed Twitter and Yahoo support (Nothing makes use of it)
  + Updated translations.
- Move the twitter specific .spec parts inside a with_twitter
  defines, which is currently set to 0 (this allows us to re-enable
  it without reworking the logic). This affects these blocks:
  + libsocialweb-branding-openSUSE BuildRequires (which contains
    the API keys)
  + the TWITTER_KEY variable setup (extracts the API keys)
  + the --*twitter* configure parameters.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Support enterprise logins via Kerberos (bgo#679253)
  + Drop the Microsoft Exchange and Windows Live icons, and use a
    transparent PNG as the fallback
  + Add a goa_client_lookup_by_id API for looking up an account
    using its ID
  + Bugs fixed: bgo#681720
  + Updated translations.
- Enable kerberos support:
  + Add krb5-mini-devel BuildRequires
  + Add pkgconfig(gcr-3) BuildRequires
  + Pass --enable-kerberos to configure.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + introspection: Add exported package information to GIR
    (bgo#680622)
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Ported to libsecret
  + Bugs fixed: bgo#670298, bgo#678907
  + Updated translations.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-1): following upstreams switch to libsecret.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Facebook is now enabled by default
  + Microsoft Exchange is enabled by default
  + The AddAccount method exposed by
    org.gnome.OnlineAccounts.Manager now requires a new argument of
    type a{sv}.
  + Methods to directly interact with the keyring are no longer
    exported as public API.
  + Updated translations:
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Bugs fixed:
  - bgo#659435: New Google authentication page doesn't fit
  - bgo#671980: Restrict the spinner's size and show a heading
    text
  - bgo#675930: Facebook web authentication window too small
  - bgo#676659: Remove custom CSS styling
  + Updated translations.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Support Microsoft Exchange using EWS
  + Add API to enable/disable Mail, Calendar, Contacts, Chat &
    Documents
  + Add org.gnome.OnlineAccounts.PasswordBased D-Bus interface
  + Request read and write access to a user's files stored in
    Skydrive
  + Improve the design of the Online Accounts panel in System
    Settings
  + Bugs fixed: bgo#669042, bgo#669625, bgo#672510, bgo#672785,
    bgo#673959, bgo#674165, bgo#674292
  + Updated translations.
- Pass --enable-exchange to configure: enable Exchange support.
- Add pkgconfig(libxml-2.0) BuildRequires: new dependency.
* Mon May 14 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + facebook: Use m.facebook.com for the authorization URI
    (bgo#675930)
  + webview: Set the SoupSession's "accept-language-auto" to TRUE
  + Updated translations.
* Tue Apr 17 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Remove the credentials from the keyring when an account is
    removed (bgo#654168).
  + Make sure the GError** passed is always pointer to NULL.
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 3.3.92.1:
  + No change, fix broken tarball.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Add a border on the webkit view (bgo#660514).
  + Build fixes.
  + Facebook related changes:
  - OAuth2Provider: add support for facebook client side auth
    flow (bgo#672060).
  - FacebookProvider: move to client-side flow (bgo#672060).
  - configure.ac: remove the facebook client secret (bgo#672060).
  - Unref the JSON parser (bgo#672060).
  - offline_access has been removed since it is deprecated.
  + Updated translations.
- Drop xz BuildRequires, as it now comes for free in the build
  system.
- Pass --enable-facebook to configure now that it doesn't require a
  secret key anymore.
* Fri Jan 13 2012 vuntz@opensuse.org
- Add baselibs.conf, as we need the 32bit package for
  evolution-data-server libraries.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.0:
  + Add support for Windows Live.
  + Facebook provider: Add Chat.
  + GoaOAuth2Based: Add ClientId and ClientSecret properties.
  + Correctly launch the preferences from the daemon.
  + Remove unused org.gnome.OnlineAccounts.PasswordBased D-Bus
    interface.
  + Build fixes.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add new --enable-windows-live option to configure.
- Split typelib file into typelib-1_0-Goa-1_0 subpackage.
- Add typelib-1_0-Goa-1_0 Requires to devel subpackage.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to version 3.2.0.1:
  + Fix a crash when launching preferences from notifications
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Let authentication webkit window inherit from GNOME proxy
    settings (bgo#658444)
  + Updated translations.
- Add pkgconfig(libsoup-gnome-2.4) BuildRequires: new dependency.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + String fixes.
  + Build fixes.
  + Updated translations.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Add a Documents account type.
  + Updated translations.
- Remove have_lang macro now that there are translations.
* Mon Jul 18 2011 dimstar@opensuse.org
- Add libsocialweb-branding-openSUSE BuildRequires. This package
  contains our API keys for the various backends.
- Pass --enable-twitter and the corresponding keys to configure.
  This allows us to enable the twitter backend for
  gnome-online-accounts. Part of bnc#703759.
- For completeness pass --enable-google to configure. It's there by
  default and it does not require API keys; anonymous works just
  fine.
* Sun Jul  3 2011 vuntz@opensuse.org
- Initial package (version 3.1.1).
